.. SubstitutionBreaker documentation master file

Welcome to SubstitutionBreaker's documentation!
===============================================

This project provides a Python implementation for breaking classical
substitution ciphers. The project is hosted on `GitLab
<https://gitlab.com/guballa/SubstitutionBreaker>`_.



.. toctree::
   :caption: Substitution Breaker
   :maxdepth: 2

   overview
   installation
   usage

.. toctree::
   :caption: Command Line Interface
   :maxdepth: 2

   cli_explained
   cli

.. toctree::
   :caption: Python API
   :maxdepth: 2

   py_explained
   subbreaker

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
